// "CHAIR.INC" POV-Ray 2.0 Include File for "HAVESEAT.POV"


// textures and finishes

#declare Chromed = texture {
	pigment { Gray45 }
	finish { ambient 0.1 diffuse 0.8 phong 0.8 phong_size 190
		 metallic reflection 0.7 brilliance 6 }
}
#declare Plastic = finish {
	diffuse 0.7 phong 1 phong_size 130 reflection 0.2
}

// chair dimensions

#declare w = 540	// width
#declare h = 800/2	// height
#declare d = 490	// depth
#declare r =  18	// tube radius
#declare R =  60	// curve radius
#declare s =   6/2	// seat thickness

// an U-shaped tube

#declare Wtube = union {
	cylinder { <R, 0, 0>, <w-R, 0, 0>, r }
	intersection { torus { R, r sturm }
		plane { x, 0 } plane { z, 0 }
		translate <R, 0, R>
	}
	intersection { torus { R, r sturm }
		plane { -x, 0 } plane { z, 0 }
		translate <w-R, 0, R>
	}
	bounded_by { box { <-r, -r, -r>, <w+r, r, R> } }
}

// two differently aligned J-shaped tubes

#declare Htube = union {
	cylinder { <0, R, 0>, <0, h-R, 0>, r }
	intersection { torus { R, r sturm rotate 90*z }
		plane { y, 0 } plane { z, 0 }
		translate <0, R, R>
	}
	bounded_by { box { <-r, -r, -r>, <r, h-R, R> } }
}
#declare Dtube = union {
	cylinder { <0, 0, R>, <0, 0, d-R>, r }
	intersection { torus { R, r sturm rotate 90*z }
		plane { y, 0 } plane { z, 0 }
		translate <0, R, R>
	}
	bounded_by { box { <-r, -r, -r>, <r, R, d-R> } }
}

// form a chair skeleton using 9 bent tubes and two capping spheres

#declare Chairtubes = union {
	object { Wtube rotate 180*x translate <0, 0, d> }
	object { Dtube }
	object { Dtube translate <w, 0, 0> }
	object { Dtube rotate 180*z translate <0, h, 0> }
	object { Dtube rotate 180*z translate <w, h, 0> }
	object { Htube }
	object { Htube translate <w, 0, 0> }
	object { Htube rotate 180*y translate <0, h, d> }
	object { Htube rotate 180*y translate <w, h, d> }
	sphere { <0, h+h-R, d>, r }
	sphere { <w, h+h-R, d>, r }
}

// the plastic seat parts

#declare Seat = union {
	merge {
		box { <0, h-s, R-0.1>, <w, h+s, d-R> }
		difference {
			cylinder { < 0, h-R, R>, <w  , h-R, R>, R+s }
			cylinder { <-1, h-R, R>, <w+1, h-R, R>, R-s }
			plane { y, h-R } plane { -z, -R }
			bounded_by {
				cylinder { <0, h-R, R>, <w, h-R, R>, R+s }
			}
		}
	}
	merge {
		box { <0, h+R, d-s>, <w, h+h-R, d+s> }
		cylinder { <0, h+h-R, d+s>, <w, h+h-R, d+s>, s }
	}
}

// construct the chair, centered on origin

#declare Chair = union {
	object { Chairtubes texture { Chromed } }
	object { Seat pigment { CadetBlue } finish { Plastic } }
	translate <-w/2, -h, -d/2>
}
