// "ROOM.INC" POV-Ray 2.0 Include File for "HAVESEAT.POV"


// declare textures

#declare WallWood = texture {
	pigment { wood turbulence 0.03 scale <1, 20, 1> color_map {
		[ 0.1	color rgb <0.40 0.26 0.18> ]
		[ 0.2	color rgb <0.70 0.49 0.38> ]
		[ 1.0	color rgb <0.75 0.52 0.40> ] }
	}
	finish { ambient 0.4 diffuse 0.5 phong 0.1 phong_size 40 }
	rotate 89*x translate <2000, 0, 2000>
}
#declare FrameWood = texture {
	pigment { wood turbulence 0.08 scale 10 color_map {
		[ 0.06	color rgb <0.60 0.50 0.42> ]
		[ 0.1	color rgb <0.80 0.77 0.74> ]
		[ 1.0	color rgb <0.94 0.94 0.92> ] }
	}
	finish { ambient 0.4 diffuse 0.5 phong 0.1 phong_size 40 }
	rotate 89*x translate <2000, 0, 2000>
}
#declare Marble = texture {
	pigment { marble turbulence 1.8 scale 200 color_map {
		[ 0.0   color rgb <0.90 0.82 0.76> ]
		[ 0.8   color rgb <0.86 0.78 0.70> ]
		[ 1.001 color rgb <0.68 0.34 0.10> ] }
	}
	finish { ambient 0.3 diffuse 0.6 phong 0.8 phong_size 80 }
}
#declare Concrete = texture {
	pigment { Gray90 }
	finish { ambient 0.7 diffuse 0.4 }
}

// room dimensions

#declare rw = 4000	// room width
#declare rd = 6000	// room depth
#declare rh = 2400	// room height
#declare t  = 100	// wall thickness
#declare ww = 2600	// window width
#declare wh = 1400	// window height
#declare wf = 60	// window frame width

#declare Floor = box { <-t, -t, -t>, <rw+t, 0, rd+t> }
#declare Ceiling = box { <-t, rh, -t>, <rw+t, rh+t, rd+t> }
#declare Backwall = box { <0, 0, rd>, <rw, rh, rd+t> }
#declare Rightwall = box { <rw, 0, 0>, <rw+t, rh, rd> }

// the window is declared to fit the left side wall

#declare Leftwall = box { <-t, 0, 0>, <0, rh, rd> }
#declare WHole = box { <-t-10, 0, 0>, <10, wh, ww>
	translate <0, 500, 1900>
}
#declare WFrame = box { <-t-8, -wf, -wf>, <1+8, wh+wf, ww+wf>
	translate <0, 500, 1900>
}

// construct the room

#declare Room = union {
	object { Floor texture { Marble } }
	object { Ceiling texture { Concrete } }
	object { Backwall texture { WallWood } }
	object { Rightwall texture { WallWood rotate 90*y } }
	difference {
		object { Leftwall texture { WallWood rotate -90*y } }
		object { WHole texture { FrameWood } }
	}
	difference {
		object { WFrame }
		object { WHole }
		texture { FrameWood }
	}
	translate <-rw/2, 0, -rd/2>
}
